==> gpt_multi_atomic_agents-0.4.0-py3-none-any.whl: gpt_multi_atomic_agents/graphql_dto.py <==
from atomic_agents.agents.base_agent import (
    BaseIOSchema,
)
from pydantic import Field


class GraphQLAgentInputSchema(BaseIOSchema):
    """
    This schema represents the input to the agent.
    The schema contains previously generated mutation calls, and the list of allowed generated mutations.
    """

    user_input: str = Field(description="The chat message from the user", default="")
    accepted_graphql_schemas: list[str] = Field(
        description="The set of GraphQL schemas which the agent can use to work with client data."
    )
    mutations_allowed_to_generate: list[str] = Field(
        description="Definitions of the GraphQL mutations that this agent can generate"
    )
    previously_generated_mutations: list[str] = Field(
        description="Previously generated GraphQL mutations in this chat (some are from other agents)",
        default_factory=lambda: list,
    )
    topics: list[str] = Field(
        description="This agent ONLY generates if user mentioned one of these topics"
    )
    # TODO - add "If data is missing, then you need to generate allowed GraphQL queries."
    graphql_data: str = Field(
        description="The input GraphQL data from the client. You need to generate allowed GraphQL mutations that the client will use to update the data.",
        default="",
    )


class GraphQLAgentOutputSchema(BaseIOSchema):
    """
    This schema represents the output of the agent.
    """

    chat_message: str = Field(description="The chat response to the user's message")
    generated_mutations: list[str] = Field(
        description="The set of new generated mutation calls to update the graphql_data. Only generate if neccessary (check if the graphql_data already has the data)."
    )
    # TODO Add generated_queries - generate queries if need more graphql_data

==> gpt_multi_atomic_agents-0.5.2-py3-none-any.whl: gpt_multi_atomic_agents/graphql_dto.py <==
from atomic_agents.agents.base_agent import (
    BaseIOSchema,
)
from pydantic import Field


class GraphQLAgentInputSchema(BaseIOSchema):
    """
    This schema represents the input to the agent.
    The schema contains previously generated mutation calls, and the list of allowed generated mutations.
    """

    user_input: str = Field(description="The chat message from the user", default="")
    accepted_graphql_schemas: list[str] = Field(
        description="The set of GraphQL schemas which the agent can use to work with client data."
    )
    mutations_allowed_to_generate: list[str] = Field(
        description="Definitions of the GraphQL mutations that this agent can generate"
    )
    previously_generated_mutations: list[str] = Field(
        description="Previously generated GraphQL mutations in this chat (some are from other agents)",
        default_factory=lambda: list,
    )
    topics: list[str] = Field(
        description="This agent ONLY generates if user mentioned one of these topics"
    )
    agent_parameters: list[str] = Field(
        description="A list of agent parameters that you can extract from the user's prompt.",
        default_factory=lambda: list,
    )
    # TODO - add "If data is missing, then you need to generate allowed GraphQL queries."
    graphql_data: str = Field(
        description="The input GraphQL data from the client. You need to generate allowed GraphQL mutations that the client will use to update the data.",
        default="",
    )


class GraphQLAgentOutputSchema(BaseIOSchema):
    """
    This schema represents the output of the agent. The chat message should be non-technical - do NOT mention GraphQL.
    """

    chat_message: str = Field(
        description="The chat response to the user's message - a friendly non-technical message. Do NOT mention GraphQL."
    )
    generated_mutations: list[str] = Field(
        description="The set of new generated mutation calls to update the graphql_data. Only generate if neccessary (check if the graphql_data already has the data)."
    )
    # TODO Add generated_queries - generate queries if need more graphql_data
